==> baseui-6.11.0.tgz: package/es/pagination/styled-components.js <==
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/*
Copyright (c) 2018 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import { styled } from '../styles/index.js';
import { StyledList } from '../menu/index.js';
import { StyledBaseButton } from '../button/index.js';
export var Root = styled('div', {
  display: 'flex',
  alignItems: 'center'
});
Root.displayName = "Root";
export var MaxLabel = styled('span', function (_ref) {
  var $theme = _ref.$theme;
  return _objectSpread({}, $theme.typography.font300, {
    marginLeft: $theme.sizing.scale300,
    marginRight: $theme.sizing.scale600
  });
});
MaxLabel.displayName = "MaxLabel";
export var DropdownContainer = styled('div', function (_ref2) {
  var $theme = _ref2.$theme;
  return {
    position: 'relative',
    marginLeft: $theme.sizing.scale600,
    marginRight: $theme.sizing.scale300
  };
});
DropdownContainer.displayName = "DropdownContainer";
export var DropdownMenu = styled(StyledList, function (_ref3) {
  var $theme = _ref3.$theme;
  return {
    position: 'absolute',
    overflow: 'auto',
    maxHeight: '200px',
    top: 'auto',
    marginTop: $theme.sizing.scale300,
    left: 0,
    right: 0,
    zIndex: 1
  };
});
DropdownMenu.displayName = "DropdownMenu";
export var DropdownButton = styled(StyledBaseButton, function (_ref4) {
  var $theme = _ref4.$theme;
  return {
    color: $theme.colors.foreground,
    minWidth: "calc(".concat($theme.sizing.scale1600, " + ").concat($theme.sizing.scale400, ")")
  };
});
DropdownButton.displayName = "DropdownButton";

==> baseui-6.20.1.tgz: package/es/pagination/styled-components.js <==
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/*
Copyright (c) 2018-2019 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import { styled } from '../styles/index.js';
import { StyledList } from '../menu/index.js';
import { StyledBaseButton } from '../button/index.js';
export var Root = styled('nav', {
  display: 'flex',
  alignItems: 'center'
});
Root.displayName = "Root";
export var MaxLabel = styled('span', function (_ref) {
  var $theme = _ref.$theme;
  return _objectSpread({}, $theme.typography.font300, {
    marginLeft: $theme.sizing.scale300,
    marginRight: $theme.sizing.scale600
  });
});
MaxLabel.displayName = "MaxLabel";
export var DropdownContainer = styled('div', function (_ref2) {
  var $theme = _ref2.$theme;
  return {
    position: 'relative',
    marginLeft: $theme.sizing.scale600,
    marginRight: $theme.sizing.scale300
  };
});
DropdownContainer.displayName = "DropdownContainer";
export var DropdownMenu = styled(StyledList, function (_ref3) {
  var $theme = _ref3.$theme;
  return {
    position: 'absolute',
    overflow: 'auto',
    maxHeight: '200px',
    top: 'auto',
    marginTop: $theme.sizing.scale300,
    left: 0,
    right: 0,
    zIndex: 1
  };
});
DropdownMenu.displayName = "DropdownMenu";
export var DropdownButton = styled(StyledBaseButton, function (_ref4) {
  var $theme = _ref4.$theme;
  return {
    color: $theme.colors.foreground,
    minWidth: "calc(".concat($theme.sizing.scale1600, " + ").concat($theme.sizing.scale400, ")")
  };
});
DropdownButton.displayName = "DropdownButton";
